**THE AUTHORITY OF INTERNATIONAL ORGANIZATIONS: THE EFFECTS OF SCOPE AND SCALE
**LIESBET HOOGHE & GARY MARKS

clear
use "RIO_pooling_delegation_replication.dta", clear

*create pooling_additive and GS_additive

*CORRELATIONS OF DEPENDENT AND INDEPENDENT VARIABLES
corr Delegation Pooling DelegationMDS PoolingMDS Delegation_alpha Pooling_alpha
corr Zscope Zmembers_log ZFH_total_av Zcapabilities2 Zweighting

**MODELS table 1: BASE MODELS**
clear
use "RIO_pooling_delegation_replication.dta", clear
regress Pooling Zmembers_log Zscope ZFH_total_av Zcapabilities2 Zweighting
predict stanresidP, rstandard
list Acronym stanresidP
list Acronym stanresidP if abs(stanresidP)>2

clear
use "RIO_pooling_delegation_replication.dta", clear
regress Delegation Zmembers_log Zscope ZFH_total_av Zcapabilities2 Zweighting
predict stanresidP2, rstandard
list Acronym stanresidP2
list Acronym stanresidP if abs(stanresidP)>2

*MODELS table 2: weighted voting either excluded from model, or incorporated in pooling measure**
*IS WEIGHTED VOTING ENDOGENOUS?
*incorporating weighting in the pooling measures*

* running the model without weighting*
**models**
clear
use "RIO_pooling_delegation_replication.dta", replace
or
use "RIO_pooling_delegation_replication.dta", replace
regress Pooling Zmembers_log Zscope ZFH_total_av Zcapabilities2
predict stanresidP, rstandard
list Acronym stanresidP
list Acronym stanresidP if abs(stanresidP)>2

regress Delegation Zmembers_log Zscope ZFH_total_av Zcapabilities2
predict stanresidP2, rstandard
list Acronym stanresidP2
list Acronym stanresidP2 if abs(stanresidP2)>2

*Robustness test for weighted voting* 
*We have incorporated info on weighted/ preferred seats in the pooling components for the 13 IOs 
*whereby weighted voting/reserved seats=supermajority*
Pooling_weighted=(Pool_access+ Pool_susp+ Pool_const+ Pool_budget+ Pool_compl+ Pool_policy)/6
reg Pooling_weighted Zmembers_log Zscope ZFH_total_av Zcapabilities2

*MODELS TABLE 3: Robustness with values at time of IO founding**
*regression -- values at creation*
regress Pooling scope_creation members_log_creation demo_mean_creation capabilities1_creation weighted_creation 
regress Delegation scope_creation members_log_creation demo_mean_creation capabilities2_creation weighted_creation 

*regression analysis for regional IOs -- two definitions**
regress Pooling Zmembers_log Zscope ZFH_total_av Zcapabilities2 Zweighting REI
regress Delegation Zmembers_log Zscope ZFH_total_av Zcapabilities2 Zweighting REI

regress Pooling Zmembers_log Zscope ZFH_total_av Zcapabilities2 Zweighting RIO
regress Delegation Zmembers_log Zscope ZFH_total_av Zcapabilities2 Zweighting RIO

****ONLINE APPENDIX: 
*(a) jackknife, bootstrapping -- Appendix D: Robustness Analyses for Table 1 
clear
use "RIO_pooling_delegation_replication.dta", clear
regress Pooling Zmembers_log Zscope ZFH_total_av Zcapabilities2 Zweighting, vce(boot)
regress Pooling Zmembers_log Zscope ZFH_total_av Zcapabilities2 Zweighting, vce(jack)

regress Delegation Zmembers_log Zscope ZFH_total_av Zcapabilities2 Zweighting, vce(boot)
regress Delegation Zmembers_log Zscope ZFH_total_av Zcapabilities2 Zweighting, vce(jack)

*(b) matching -- Appendix E: Matching weighted propensities
*matching: treatment = scope_dichotomous*
gen scope_dichotomous=scope
replace scope_dichotomous= 0 if scope_dichotomous<12
replace scope_dichotomous=1 if scope_dichotomous>=12
clear
use "RIO_pooling_delegation_replication.dta" 
cem Zmembers_log , treatment( scope_dichotomous )
keep if cem_matched==1
regress Delegation Zscope  ZFH_total_av Zcapabilities2 Zweighting [iweight=cem_weights]
regress Pooling  Zscope  ZFH_total_av Zcapabilities2 Zweighting [iweight=cem_weights]
drop cem_strata cem_matched cem_weights
clear

use "RIO_pooling_delegation_replication.dta" 
cem Zcapabilities2, treatment( scope_dichotomous )
keep if cem_matched==1
regress Delegation Zmembers_log Zscope  ZFH_total_av Zweighting [iweight=cem_weights]
regress Pooling Zmembers_log Zscope  ZFH_total_av  Zweighting [iweight=cem_weights]
drop cem_strata cem_matched cem_weights
clear

use "RIO_pooling_delegation_replication.dta" 
cem ZFH_total_av , treatment( scope_dichotomous )
keep if cem_matched==1
regress Delegation Zmembers_log Zscope   Zcapabilities2 Zweighting [iweight=cem_weights]
regress Pooling Zmembers_log Zscope   Zcapabilities2 Zweighting [iweight=cem_weights]
drop cem_strata cem_matched cem_weights
clear

use "RIO_pooling_delegation_replication.dta" 
cem Zweighting , treatment( scope_dichotomous )
keep if cem_matched==1
regress Delegation Zmembers_log Zscope  ZFH_total_av Zcapabilities2  [iweight=cem_weights]
regress Pooling Zmembers_log Zscope  ZFH_total_av Zcapabilities2  [iweight=cem_weights]
drop cem_strata cem_matched cem_weights
clear

*matching: treatment = members_dichotomous*
gen members_dichotomous = members_log
recode members_dichotomous (min/1.49=0) (1.50/max=1)

use "RIO_pooling_delegation_replication.dta" 
cem  Zscope , treatment( members_dichotomous  )
keep if cem_matched==1
regress Delegation Zmembers_log ZFH_total_av Zcapabilities2 Zweighting [iweight=cem_weights]
regress Pooling Zmembers_log ZFH_total_av Zcapabilities2 Zweighting [iweight=cem_weights]
drop cem_strata cem_matched cem_weights
clear

use "RIO_pooling_delegation_replication.dta" 
cem Zcapabilities2  , treatment( members_dichotomous )
keep if cem_matched==1
regress Delegation Zmembers_log Zscope  ZFH_total_av Zweighting [iweight=cem_weights]
regress Pooling Zmembers_log Zscope  ZFH_total_av  Zweighting [iweight=cem_weights]
drop cem_strata cem_matched cem_weights
clear

use "RIO_pooling_delegation_replication.dta" 
cem ZFH_total_av , treatment( members_dichotomous )
keep if cem_matched==1
regress Delegation Zmembers_log Zscope Zcapabilities2 Zweighting [iweight=cem_weights]
regress Pooling Zmembers_log Zscope  Zcapabilities2 Zweighting [iweight=cem_weights]
drop cem_strata cem_matched cem_weights
clear

use "RIO_pooling_delegation_replication.dta" 
cem Zweighting, treatment( members_dichotomous )
keep if cem_matched==1
regress Delegation Zmembers_log Zscope  ZFH_total_av Zcapabilities2  [iweight=cem_weights]
regress Pooling Zmembers_log Zscope  ZFH_total_av Zcapabilities2  [iweight=cem_weights]
drop cem_strata cem_matched cem_weights
clear

use "RIO_pooling_delegation_replication.dta" 
**GRAPHS**

*Figure 1: plot pooling and delegation*

. twoway (scatter Pooling Delegation, sort mlabel(Acronym)), ytitle(POOLING) xtitle(DELEGATION)

*Figure 3: marginal effects plot*
regress Pooling Zscope Zmembers_log ZFH_total_av Zcapabilities2 Zweighting 
margins, dydx(*)
marginsplot

regress Delegation Zscope Zmembers_log ZFH_total_av Zcapabilities2 Zweighting
margins, dydx(*)
marginsplot

*Figure 2: MARGINSPLOT DELEGATION AND SCOPE
regress Delegation scope Zmembers_log ZFH_total_av Zcapabilities2 Zweighting 
margins, at(scope=(0(5)25))
marginsplot, recast (line) recastci(rarea) xtitle (Policy scope) ytitle (Delegation) xscale (range (1 25))

*Figure 2: MARGINSPLOT POOLING AND SCOPE
regress Pooling scope Zmembers_log ZFH_total_av Zcapabilities2 Zweighting 
margins, at(scope=(0(5)25))
marginsplot, recast (line) recastci(rarea) xtitle (Policy scope) ytitle (Pooling) xscale (range (1 25))


